#
# spec file for package python-rq
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name rq
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-rq
Version:        1.4.3
Release:        bp156.3.2
Summary:        Easy Job Queues for Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/rq/rq
Source:         https://github.com/rq/rq/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module click >= 3.0}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis >= 3.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  psmisc
BuildRequires:  python-rpm-macros
BuildRequires:  redis
Requires:       python-click >= 3.0
Requires:       python-redis >= 3.0.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
RQ (Redis Queue) is a simple Python library for queueing jobs and processing
them in the background with workers. It is backed by Redis. It can be
integrated into web stacks.

%prep
%setup -q -n %{mod_name}-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/rq
%python_clone -a %{buildroot}%{_bindir}/rqinfo
%python_clone -a %{buildroot}%{_bindir}/rqworker
%python_expand rm -r %{buildroot}%{$python_sitelib}/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_failure_capture - circular dependency on sentry-sdk
# test_worker - update-alternatives: only rqworker-%{python_version} is
#               available, skip test for simplicity
export PATH="$PATH:%{buildroot}%{_bindir}"
%{_sbindir}/redis-server --port 6379 &
%pytest -k 'not (test_failure_capture or test_worker)'
killall redis-server

%post
%python_install_alternative rq
%python_install_alternative rqinfo
%python_install_alternative rqworker

%postun
%python_uninstall_alternative rq
%python_uninstall_alternative rqinfo
%python_uninstall_alternative rqworker

%files %{python_files}
%doc README.md CHANGES.md
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/rq
%python_alternative %{_bindir}/rqinfo
%python_alternative %{_bindir}/rqworker

%changelog
* Wed Jul 22 2020 ecsos <ecsos@opensuse.org>
- Update to 1.4.3
  * Added job.get_position() and queue.get_job_position(). Thanks @aparcar!
  * Longer TTLs for worker keys to prevent them from expiring inside the worker lifecycle. Thanks @selwin!
  * Long job args/kwargs are now truncated during logging. Thanks @JhonnyBn!
  * job.requeue() now returns the modified job. Thanks @ericatkin!
- Fix build error for Leap: Since 1.4.0 rq require python >= 3.4.
* Thu Jun 11 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.4.2:
  * RQ 1.4.2 (2020-05-26)
    + Reverted changes to hmset command which causes workers on Redis server < 4 to crash. Thanks @selwin!
    + Merged in more groundwork to enable jobs with multiple dependencies. Thanks @thomasmatecki!
  * RQ 1.4.1 (2020-05-16)
    + Default serializer now uses pickle.HIGHEST_PROTOCOL for backward compatibility reasons. Thanks @bbayles!
    + Avoid deprecation warnings on redis-py >= 3.5.0. Thanks @bbayles!
  * RQ 1.4.0 (2020-05-13)
    + Custom serializer is now supported. Thanks @solababs!
    + delay() now accepts job_id argument. Thanks @grayshirt!
    + Fixed a bug that may cause early termination of scheduled or requeued jobs. Thanks @rmartin48!
    + When a job is scheduled, always add queue name to a set containing active RQ queue names. Thanks @mdawar!
    + Added --sentry-ca-certs and --sentry-debug parameters to rq worker CLI. Thanks @kichawa!
    + Jobs cleaned up by StartedJobRegistry are given an exception info. Thanks @selwin!
* Wed Jun 10 2020 Marcus Rueckert <mrueckert@suse.de>
- BR redis to make the testsuite work
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Mar 19 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.0:
  * RQ 1.3.0 (2020-03-09)
    + Support for infinite job timeout. Thanks @theY4Kman!
    + Added __main__ file so you can now do python -m rq.cli. Thanks @bbayles!
    + Fixes an issue that may cause zombie processes. Thanks @wevsty!
    + job_id is now passed to logger during failed jobs. Thanks @smaccona!
    + queue.enqueue_at() and queue.enqueue_in() now supports explicit args and kwargs function invocation. Thanks @selwin!
  * RQ 1.2.2 (2020-01-31)
    + Job.fetch() now properly handles unpickleable return values. Thanks @selwin!
  * RQ 1.2.1 (2020-01-31)
    + enqueue_at() and enqueue_in() now sets job status to scheduled. Thanks @coolhacker170597!
    + Failed jobs data are now automatically expired by Redis. Thanks @selwin!
    + Fixes RQScheduler logging configuration. Thanks @FlorianPerucki!
  * RQ 1.2.0 (2020-01-04)
    + This release also contains an alpha version of RQ's builtin job scheduling mechanism. Thanks @selwin!
    + Various internal API changes in preparation to support multiple job dependencies. Thanks @thomasmatecki!
    + --verbose or --quiet CLI arguments should override --logging-level. Thanks @zyt312074545!
    + Fixes a bug in rq info where it doesn't show workers for empty queues. Thanks @zyt312074545!
    + Fixed queue.enqueue_dependents() on custom Queue classes. Thanks @van-ess0!
    + RQ and Python versions are now stored in job metadata. Thanks @eoranged!
    + Added failure_ttl argument to job decorator. Thanks @pax0r!
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from description.
* Mon Aug 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.0:
  * Many feature updates and bugfixes to support new python stack
- Execute tests
* Mon Feb  4 2019 Marcus Rueckert <mrueckert@suse.de>
- initial package
